# django-tasks-pg

Yes, I'm kinda parking on this because I want to motivate myself to make it. I've enjoyed learning about and using postgres as an easy task queue backend and using some processes to run a few of these things at a time.

Ideally there will be something like:

```sh
python manage.py run_pg_worker
```

And you're running a simple, single process worker that pulls tasks from the queue, runs the function.

Task discovery and registration is probably something we get from the framework, I'm hoping this is easy enough to get running but also have fun.
